HooksDef

Struct HooksDef 

pub struct HooksDef {
    pub hooks: Vec<Hook>,
    pub file_path: Option<String>,
}
Definition of hooks — optional, None = empty ActiveModelBehavior

Fields

hooks: Vec<Hook>file_path: Option<String>

Implementations

Source

impl HooksDef

pub fn new() -> Self

Creates an empty hook set.

pub fn from_file(path: impl Into<String>) -> Self

Points to an external file containing business logic

pub fn add( self, hook_type: HookType, slot: u8, handler: impl Into<String>, ) -> Self

Registers a hook of hook_type at slot, pointing to handler. Hooks are kept sorted by slot after every insertion, so execution order is always consistent regardless of registration order.

pub fn before_save(self, slot: u8, handler: impl Into<String>) -> Self

Registers a BeforeSave hook at slot.

pub fn after_save(self, slot: u8, handler: impl Into<String>) -> Self

Registers an AfterSave hook at slot.

pub fn before_delete(self, slot: u8, handler: impl Into<String>) -> Self

Registers a BeforeDelete hook at slot.

pub fn after_delete(self, slot: u8, handler: impl Into<String>) -> Self

Registers an AfterDelete hook at slot.