ActiveHasMany

Enum ActiveHasMany 

#[non_exhaustive]
pub enum ActiveHasMany<E>
where E: EntityTrait,
{ NotSet, Replace(Vec<<E as EntityTrait>::ActiveModelEx>), Append(Vec<<E as EntityTrait>::ActiveModelEx>), }
State carried by a has_many (or many-to-many) field on an ActiveModelEx. Chooses between “leave alone”, “additive write”, and “destructive replace” semantics.

Unstable: nested-ActiveModel relation mutation is exempt from semver — the semantics of replacing or removing related records may change in a minor (2.x) release.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NotSet

Field is absent; existing related models are left as-is on save.



Replace(Vec<<E as EntityTrait>::ActiveModelEx>)

Persist exactly this list of related models, deleting any existing children that are not in the list.



Append(Vec<<E as EntityTrait>::ActiveModelEx>)

Persist these related models alongside any existing children; never deletes.

Implementations

Source

impl<E> ActiveHasMany<E>
where E: EntityTrait,

pub fn take(&mut self) -> ActiveHasMany<E>

Take ownership of the models, leaving NotSet in place

pub fn as_slice(&self) -> &[<E as EntityTrait>::ActiveModelEx]

Borrow models as slice

pub fn as_mut_vec(&mut self) -> &mut Vec<<E as EntityTrait>::ActiveModelEx>

Get a mutable vec. If self is NotSet, convert to append.

pub fn into_vec(self) -> Vec<<E as EntityTrait>::ActiveModelEx>

Consume self as vector

pub fn empty_holder(&self) -> ActiveHasMany<E>

Returns an empty container of self

pub fn push<AM>(&mut self, model: AM) -> &mut ActiveHasMany<E>
where AM: Into<<E as EntityTrait>::ActiveModelEx>,

Push an item to self

pub fn append<AM>(&mut self, model: AM) -> &mut ActiveHasMany<E>
where AM: Into<<E as EntityTrait>::ActiveModelEx>,

Push an item to self, but convert Replace to Append

pub fn replace_all<I>(&mut self, models: I) -> &mut ActiveHasMany<E>
where I: IntoIterator<Item = <E as EntityTrait>::ActiveModelEx>,

Replace all items in this set

pub fn convert_to_append(&mut self) -> &mut ActiveHasMany<E>

Convert self to Append, if set

pub fn not_set(&mut self)

Reset self to NotSet

pub fn is_replace(&self) -> bool

If self is Replace

pub fn is_append(&self) -> bool

If self is Append

pub fn is_changed(&self) -> bool

Return true if self is Replace or any containing model is changed

pub fn find(&self, model: &<E as EntityTrait>::Model) -> bool

Find within the models by primary key, return true if found

pub fn try_into_model(self) -> Result<HasMany<E>, DbErr>

Convert this back to a ModelEx container